==> haskell-hedgehog-classes-0.2.5.4-120-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hedgehog-classes.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hedgehog-classes
version:              0.2.5.4
visibility:           public
id:                   hedgehog-classes-0.2.5.4-6sLetdkVp775ITrr2WQ3IE
key:                  hedgehog-classes-0.2.5.4-6sLetdkVp775ITrr2WQ3IE
license:              BSD-3-Clause
copyright:            2020 chessai
maintainer:           chessai1996@gmail.com
author:               chessai
homepage:             https://github.com/hedgehogqa/haskell-hedgehog-classes
synopsis:             Hedgehog will eat your typeclass bugs
description:
    This library provides Hedgehog properties to ensure
    that typeclass instances adhere to the set of laws
    that they are supposed to. There are other libraries
    that do similar things, such as `genvalidity-hspec` and `checkers`.
    This library differs from other solutions by not introducing any
    new typeclasses that the user needs to learn, and otherwise minimal
    API overhead.

    This library is directly inspired by `quickcheck-classes`.

category:             Testing
abi:                  fb26906e0e323cd94801e8dff860eb90
exposed:              True
exposed-modules:      Hedgehog.Classes
hidden-modules:
    Hedgehog.Classes.Alternative Hedgehog.Classes.Applicative
    Hedgehog.Classes.Arrow Hedgehog.Classes.Bifoldable
    Hedgehog.Classes.Bifunctor Hedgehog.Classes.Binary
    Hedgehog.Classes.Bitraversable Hedgehog.Classes.Bits
    Hedgehog.Classes.Category Hedgehog.Classes.Common
    Hedgehog.Classes.Common.ApTrans Hedgehog.Classes.Common.Bottom
    Hedgehog.Classes.Common.Compat Hedgehog.Classes.Common.Equation
    Hedgehog.Classes.Common.Func Hedgehog.Classes.Common.Gen
    Hedgehog.Classes.Common.IO Hedgehog.Classes.Common.Laws
    Hedgehog.Classes.Common.Property Hedgehog.Classes.Common.PP
    Hedgehog.Classes.Comonad Hedgehog.Classes.Contravariant
    Hedgehog.Classes.Enum Hedgehog.Classes.Eq Hedgehog.Classes.Foldable
    Hedgehog.Classes.Functor Hedgehog.Classes.Generic
    Hedgehog.Classes.Integral Hedgehog.Classes.Json
    Hedgehog.Classes.Monad Hedgehog.Classes.MonadIO
    Hedgehog.Classes.MonadPlus Hedgehog.Classes.MonadZip
    Hedgehog.Classes.Monoid Hedgehog.Classes.MVector
    Hedgehog.Classes.Ord Hedgehog.Classes.Prim
    Hedgehog.Classes.Semigroup Hedgehog.Classes.Semiring
    Hedgehog.Classes.Show Hedgehog.Classes.ShowRead
    Hedgehog.Classes.Storable Hedgehog.Classes.Traversable

import-dirs:          /usr/lib/ghc-9.4.8/site-local/hedgehog-classes-0.2.5.4
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hedgehog-classes-0.2.5.4
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hedgehog-classes-0.2.5.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hedgehog-classes
hs-libraries:         HShedgehog-classes-0.2.5.4-6sLetdkVp775ITrr2WQ3IE
depends:
    aeson-2.1.2.1-17AWhWkbfJE926UMi0wPlA base-4.17.2.1 binary-0.8.9.1
    comonad-5.0.9-9C1h3ebsgHwG8wsLv8qQjA containers-0.6.7
    hedgehog-1.3-FDpy5y0SnN48j2uzk5M7B1
    pretty-show-1.10-Il8DKxKkDEW3pjtvdJ1ynD
    primitive-0.8.0.0-KvNzOAcw1vIIZ8l6YzsRlk
    semirings-0.6-BYpt4WkWcIZHx1tJXuBZmN
    silently-1.2.5.4-9u7UVppGqLDJYp1Db2hbZU transformers-0.5.6.2
    vector-0.13.1.0-Dc65CzydytHE52tdajtbOv
    wl-pprint-annotated-0.1.0.1-Ek32DEosuBH1RA9WKaDE7b

haddock-interfaces:
    /usr/share/doc/haskell-hedgehog-classes/html/hedgehog-classes.haddock

haddock-html:         /usr/share/doc/haskell-hedgehog-classes/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hedgehog-classes-0.2.5.4-121-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hedgehog-classes.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hedgehog-classes
version:              0.2.5.4
visibility:           public
id:                   hedgehog-classes-0.2.5.4-6eHFD6RSR1SJ80sFHZD7nO
key:                  hedgehog-classes-0.2.5.4-6eHFD6RSR1SJ80sFHZD7nO
license:              BSD-3-Clause
copyright:            2020 chessai
maintainer:           chessai1996@gmail.com
author:               chessai
homepage:             https://github.com/hedgehogqa/haskell-hedgehog-classes
synopsis:             Hedgehog will eat your typeclass bugs
description:
    This library provides Hedgehog properties to ensure
    that typeclass instances adhere to the set of laws
    that they are supposed to. There are other libraries
    that do similar things, such as `genvalidity-hspec` and `checkers`.
    This library differs from other solutions by not introducing any
    new typeclasses that the user needs to learn, and otherwise minimal
    API overhead.

    This library is directly inspired by `quickcheck-classes`.

category:             Testing
abi:                  b7833b8463c259246eb585dc38ddd76a
exposed:              True
exposed-modules:      Hedgehog.Classes
hidden-modules:
    Hedgehog.Classes.Alternative Hedgehog.Classes.Applicative
    Hedgehog.Classes.Arrow Hedgehog.Classes.Bifoldable
    Hedgehog.Classes.Bifunctor Hedgehog.Classes.Binary
    Hedgehog.Classes.Bitraversable Hedgehog.Classes.Bits
    Hedgehog.Classes.Category Hedgehog.Classes.Common
    Hedgehog.Classes.Common.ApTrans Hedgehog.Classes.Common.Bottom
    Hedgehog.Classes.Common.Compat Hedgehog.Classes.Common.Equation
    Hedgehog.Classes.Common.Func Hedgehog.Classes.Common.Gen
    Hedgehog.Classes.Common.IO Hedgehog.Classes.Common.Laws
    Hedgehog.Classes.Common.Property Hedgehog.Classes.Common.PP
    Hedgehog.Classes.Comonad Hedgehog.Classes.Contravariant
    Hedgehog.Classes.Enum Hedgehog.Classes.Eq Hedgehog.Classes.Foldable
    Hedgehog.Classes.Functor Hedgehog.Classes.Generic
    Hedgehog.Classes.Integral Hedgehog.Classes.Json
    Hedgehog.Classes.Monad Hedgehog.Classes.MonadIO
    Hedgehog.Classes.MonadPlus Hedgehog.Classes.MonadZip
    Hedgehog.Classes.Monoid Hedgehog.Classes.MVector
    Hedgehog.Classes.Ord Hedgehog.Classes.Prim
    Hedgehog.Classes.Semigroup Hedgehog.Classes.Semiring
    Hedgehog.Classes.Show Hedgehog.Classes.ShowRead
    Hedgehog.Classes.Storable Hedgehog.Classes.Traversable

import-dirs:          /usr/lib/ghc-9.4.8/site-local/hedgehog-classes-0.2.5.4
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hedgehog-classes-0.2.5.4
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hedgehog-classes-0.2.5.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hedgehog-classes
hs-libraries:         HShedgehog-classes-0.2.5.4-6eHFD6RSR1SJ80sFHZD7nO
depends:
    aeson-2.1.2.1-CJUEk8Q0QXZ63rfmeHQCzY base-4.17.2.1 binary-0.8.9.1
    comonad-5.0.9-178kmWrlefq4Vhns6stMp9 containers-0.6.7
    hedgehog-1.3-51ynte3Qpg8FNXfqPMrXBg
    pretty-show-1.10-Il8DKxKkDEW3pjtvdJ1ynD
    primitive-0.8.0.0-AkaLl3oBd0zGZjVVLiSfZ
    semirings-0.6-DFzSnDIXsNZ2pSrJEkm1BU
    silently-1.2.5.4-9u7UVppGqLDJYp1Db2hbZU transformers-0.5.6.2
    vector-0.13.1.0-4yrO9MMzvlSAj3sbKvUmkp
    wl-pprint-annotated-0.1.0.1-Ek32DEosuBH1RA9WKaDE7b

haddock-interfaces:
    /usr/share/doc/haskell-hedgehog-classes/html/hedgehog-classes.haddock

haddock-html:         /usr/share/doc/haskell-hedgehog-classes/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
